@@ -1,5 +1,5 @@
 #!/usr/bin/perl -w
-# Copyright (c) 2010-2019 Sullivan Beck.  All rights reserved.
+# Copyright (c) 2010-2020 Sullivan Beck.  All rights reserved.
 # This program is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
 
@@ -500,6 +500,8 @@ $Data{'language'}{'iana'}{'orig'}{'name'} = {
    "Haiǁom"                                        => "Haiom",
    "ǁAni"                                          => "Ani",
    "ǂHua"                                          => "Hua",
+   "ǂʼAmkhoe"                                      => "Amkhoe",
+   "Tłı̨chǫ"                                        => "Tllcho",
    "Juǀʼhoan"                                       => "Juhoan",
    "Nǀu"                                           => "Nu",
    "ǃXóõ"                                          => "Xoo",
