@@ -1,5 +1,5 @@
 #!/usr/bin/perl -w
-# Copyright (c) 2011-2017 Sullivan Beck.  All rights reserved.
+# Copyright (c) 2011-2020 Sullivan Beck.  All rights reserved.
 # This program is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
 
@@ -30,6 +30,11 @@ $Data{'langvar'}{'iana'}{'orig'}{'name'} = {
    "Portuguese-Brazilian Orthographic Convention of 1945 (Convencao Ortografica Luso-Brasileira de 1945)",
    "Portuguese Language Orthographic Agreement of 1990 (Acordo Ortográfico da Língua Portuguesa de 1990)" =>
    "Portuguese Language Orthographic Agreement of 1990 (Acordo Ortografico da Lingua Portuguesa de 1990)",
+   "Niçard"                           => "Nicard",
+   "Provençal"                       => "Provencal",
+   "Østgrønlands"                 =>"Ostgronlands",
+   "Latvian orthography used before 1920s (\"vecā druka\")" =>
+   "Latvian orthography used before 1920s (\"veca druka\")",
 };
 
 $Data{'langvar'}{'iana'}{'ignore'} = {
